@@ -12,6 +12,11 @@ pub struct ActorError {
     msg: String,
 }
 
+pub const SYS_FORBIDDEN: ExitCode = ExitCode::new(8);
+pub const SYS_ILLEGAL_ACTOR: ExitCode = ExitCode::new(9);
+pub const SYS_ILLEGAL_ARGUMENT: ExitCode = ExitCode::new(10);
+pub const USR_PLACEHOLDER: ExitCode = ExitCode::new(1000);
+
 impl ActorError {
     pub fn new(exit_code: ExitCode, msg: String) -> Self {
         Self { exit_code, msg }
@@ -24,7 +29,7 @@ impl ActorError {
 
     /// Returns true when the exit code is `Ok`.
     pub fn is_ok(&self) -> bool {
-        self.exit_code == ExitCode::Ok
+        self.exit_code == ExitCode::OK
     }
 
     /// Error message of the actor error.
@@ -42,13 +47,13 @@ impl ActorError {
 // TODO former EncodingError
 impl From<fvm_ipld_encoding::Error> for ActorError {
     fn from(e: fvm_ipld_encoding::Error) -> Self {
-        Self { exit_code: ExitCode::ErrSerialization, msg: e.to_string() }
+        Self { exit_code: ExitCode::USR_SERIALIZATION, msg: e.to_string() }
     }
 }
 
 /// Converts an actor deletion error into an actor error with the appropriate exit code. This
 /// facilitates propagation.
-#[cfg(target_arch = "wasm32")]
+#[cfg(feature = "fil-actor")]
 impl From<fvm_sdk::error::ActorDeleteError> for ActorError {
     fn from(e: fvm_sdk::error::ActorDeleteError) -> Self {
         use fvm_sdk::error::ActorDeleteError::*;
@@ -56,8 +61,8 @@ impl From<fvm_sdk::error::ActorDeleteError> for ActorError {
             // FIXME: These shouldn't be "system" errors, but we're trying to match existing
             // behavior here.
             exit_code: match e {
-                BeneficiaryIsSelf => ExitCode::SysErrIllegalActor,
-                BeneficiaryDoesNotExist => ExitCode::SysErrIllegalArgument,
+                BeneficiaryIsSelf => SYS_ILLEGAL_ACTOR,
+                BeneficiaryDoesNotExist => SYS_ILLEGAL_ARGUMENT,
             },
             msg: e.to_string(),
         }
@@ -66,13 +71,13 @@ impl From<fvm_sdk::error::ActorDeleteError> for ActorError {
 
 /// Converts a no-state error into an an actor error with the appropriate exit code (illegal actor).
 /// This facilitates propagation.
-#[cfg(target_arch = "wasm32")]
+#[cfg(feature = "fil-actor")]
 impl From<fvm_sdk::error::NoStateError> for ActorError {
     fn from(e: fvm_sdk::error::NoStateError) -> Self {
         Self {
             // FIXME: These shouldn't be "system" errors, but we're trying to match existing
             // behavior here.
-            exit_code: ExitCode::SysErrIllegalActor,
+            exit_code: SYS_ILLEGAL_ACTOR,
             msg: e.to_string(),
         }
     }
