@@ -23,18 +23,8 @@ where
     }
 
     // send 0 balance to the account so an ID address for it is created and then try to resolve
-    rt.send(
-        *address,
-        METHOD_SEND,
-        Default::default(),
-        Default::default(),
-    )
-    .map_err(|e| {
-        e.wrap(&format!(
-            "failed to send zero balance to address {}",
-            address
-        ))
-    })?;
+    rt.send(*address, METHOD_SEND, Default::default(), Default::default())
+        .map_err(|e| e.wrap(&format!("failed to send zero balance to address {}", address)))?;
 
     rt.resolve_address(address).ok_or_else(|| {
         anyhow::anyhow!(
